@@ -139,3 +139,20 @@ class IncorrectNestedResourceKwargs(PrettyException):
     """
     pass
 
+
+
+class MissingCsrfTokenInCookies(PrettyException):
+    """Raised when no CSRF token could be found in a session's cookies.
+
+    This exception normally occurs when no CSRF token was passed to a
+    HTTPSessionAuth object and there was no user authentication prior (which
+    returned a CSRF token)."""
+    pass
+
+class OrderByRequiredForReverse(PrettyException):
+    """Raised by QuerySet when attempting to reverse a query without an order.
+
+    This exception will be raised when attempting to evaluate a QuerySet that
+    should be reversed (ie. reverse() has been called at least once), but does
+    not have an order.
+    """
